@@ -9,6 +9,8 @@ import urllib2
 
 from objectifier import Objectifier
 
+import settings
+
 API_BASE = "https://graph.facebook.com/"
 
 class FacebookError(Exception):
@@ -43,7 +45,11 @@ class FacebookCall(object):
 
     def __call__(self, method='GET', **kwargs):
         endpoint = "/".join(self.endpoint_components)
-        kwargs['access_token'] = self.token
+
+        if self.token is None:
+            kwargs.update(settings.ACCESS_TOKEN_PARAMS)
+        else:
+            kwargs['access_token'] = self.token
 
         # Format dats with Unix timestamps instead of ISO-8601.
         # kwargs['date_format'] = 'U'
@@ -65,8 +71,12 @@ class FacebookCall(object):
             raise FacebookError(message=message, type=type, code=e.code)
 
         data = response.read()
+
+        if 'text/plain' in response.headers['content-type']:
+            return Objectifier(cgi.parse_qsl(data))
+
         try:
-            response_obj = Objectifier(json.loads(data))
+            response_obj = Objectifier(data)
         except ValueError:
             return data
 
@@ -86,7 +96,7 @@ class Facebook(object):
     >>> facebook.me.checkins()
     """
 
-    def __init__(self, token):
+    def __init__(self, token=None):
         self.token = token
 
     def __getitem__(self, k):
